import { CoreDaemon } from './core.js';
import { CoreWallet } from './wallet.js';
import { TxBytes, TxData } from '@scrow/tapscript';
import { BlockQuery, ClientConfig, MethodArgs, ScanAction, ScanObject, ScanResults, CoreConfig, CmdConfig, TxStatus, BlockData, BlockHeader } from '../types/index.js';
export declare class CoreClient {
    readonly _core: CoreDaemon;
    readonly _opt: CoreConfig;
    params: string[];
    _cache: [string, unknown];
    _faucet: CoreWallet | null;
    constructor(core: CoreDaemon, config?: Partial<ClientConfig>);
    get opt(): CoreConfig;
    get chain_info(): Promise<Record<string, any>>;
    get core(): CoreDaemon;
    get wallets_loaded(): Promise<string[]>;
    get wallets_created(): Promise<string[]>;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, config?: Partial<CmdConfig>): Promise<T>;
    _get_block_data(query: BlockQuery, txdata?: boolean): Promise<BlockHeader>;
    get_block(query: BlockQuery): Promise<BlockData>;
    get_header(query: BlockQuery): Promise<BlockHeader>;
    scan_txout(action: ScanAction, ...desc: (string | ScanObject)[]): Promise<ScanResults>;
    mine_blocks(count?: number, addr?: string): Promise<Record<string, string>>;
    get_tx(txid: string): Promise<{
        status: TxStatus;
        txid: string;
        hex: string;
        size: number;
        weight: number;
        version: number;
        locktime: number;
        vin: {
            txid: string;
            vout: number;
            scriptSig: string;
            sequence: number;
            witness: string[];
        }[];
        vout: {
            scriptPubKey: import("../types/info.js").ScriptKeyResult;
            value: number;
        }[];
    } | null>;
    get_utxos(addr: string): Promise<import("../types/scan.js").UTXOResult[]>;
    load_wallet(name: string): Promise<CoreWallet>;
    load_wallets(...labels: string[]): Promise<Record<string, CoreWallet>>;
    publish_tx(txdata: TxBytes | TxData, confirm?: boolean): Promise<string>;
}
//# sourceMappingURL=client.d.ts.map